/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 *  WebSphere sMash
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */

package zero.security.example.openid;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import zero.core.context.GlobalContext;
import zero.core.context.GlobalContextURIs.Event;
import zero.core.context.GlobalContextURIs.Request;
import zero.core.cookie.Cookie;
import zero.core.security.relying.party.openid.OpenIDResolver;
import zero.core.security.relying.party.tokens.RPClaim;
import zero.core.security.relying.party.tokens.RPSecurityToken;
import zero.core.security.util.Base64;
import zero.json.Json;

public class ExampleOpenIDResolver extends OpenIDResolver{
	public static final String ExampleOpenIDResolverCookie = "simpleRegistration";
    private static final String TRUSTED_OPENID_SERVER = "http://blueid.bluehost.ibm.com/?user=";

    @Override
    public void onResolveFederatedId() {
        super.onResolveFederatedId();
        
        RPSecurityToken sToken = (RPSecurityToken) GlobalContext.zget(Event._self + "/token", null);
        if(sToken != null){
            List<RPClaim> claims = sToken.getClaims();
            if(claims != null){
                Map<String, String> claimsMap = new HashMap<String, String>();
                for (RPClaim claim : claims){
                    Iterator<Object> iter = claim.getValues();
                    if(iter.hasNext()){
                    	claimsMap.put(claim.getType().getDisplayName(), (String)iter.next());
                    }
                }
                try{
                	addCookie(Base64.encode(Json.encode(claimsMap).getBytes("UTF-8")));
                }catch (Exception e){
                    throw new RuntimeException (e);
                }
            }
        }
    }

    @Override
    protected void attachUserToken(String username) {
        if (username.startsWith(TRUSTED_OPENID_SERVER)){
            // consider this user trusted for this app and just use the userid in token and remoteUser
            username = username.substring(TRUSTED_OPENID_SERVER.length());
        }
        super.attachUserToken(username);
    }
    
    // This is configured to be called on logout
    public void onInvalidateToken()
    {
    	removeCookie();
    }
    public static void addCookie (String value)
    {
        Cookie registrationCookie = new Cookie(ExampleOpenIDResolverCookie, value);
        GlobalContext.zpost(Request.Cookies.out, registrationCookie);
    }
    
    public static void removeCookie ()
    {
        Cookie registrationCookie = new Cookie(ExampleOpenIDResolverCookie,"");
        registrationCookie.setMaxAge(0); // delete cookie
        GlobalContext.zpost(Request.Cookies.out, registrationCookie);
    }

}
